@@ -14,4 +14,4 @@ cd $1
 	find -iname \*.txt | xargs grep -l '^[[:space:]]*\.topic[[:space:]]\+[_a-zA-Z0-9]\+'
 
 # Remove the ./, Convert / to \, Convert \n to \r\n and Append to the hhp.
-} | sed -e 's/[.]\///g' | tr / '\\' | gawk 'BEGIN { ORS = "\r\n" } { print }' >> `find \#recreated -iname \*.hhp`
+} | sed -e 's/[.]\///g' | tr / '\\' | awk 'BEGIN { ORS = "\r\n" } { print }' >> `find \#recreated -iname \*.hhp`
