@@ -57,6 +57,8 @@ bool lcid_success = false; /* For later, when its dumping is added */
 bool print_defaults = false;
 bool print_blurb = true;
 bool print_stats = true;
+bool print_entity_refs = false;
+bool recreate_html = false;
 bool process_options = true;
 
 
@@ -110,6 +112,8 @@ int main( int argc, char* argv[] ){
 				case 'p': print_defaults = true; break;
 				case 'b': print_blurb = false; break;
 				case 's': print_stats = false; break;
+				case 'e': print_entity_refs = true; break;
+				case 'f': recreate_html = true; break;
 				case '-': process_options = false; break;
 				case 'h':
 					print_usage();
@@ -262,6 +266,9 @@ int main( int argc, char* argv[] ){
 			process_html_files();
 #endif*/
 
+			if( recreate_html )
+				recreate_html_from_fts();
+
 			close_strings();
 
 			/* Clean up the mess we made */
