@@ -21,7 +21,8 @@ typedef char bool;
 #define true 1
 #define false 0
 
-typedef DWORD ENCINT; /* Encoded integer base type. This can be increased in size if need be to support huge files */
+typedef DWORD ENCINT; /* Encoded integer base type. This can be increased in size if need be */
+typedef DWORD SRINT; /* Encoded integer base type. This can be increased in size if need be */
 typedef DWORD LCID;
 typedef QWORD FILETIME;
 
@@ -36,12 +37,15 @@ bool read_WORD( FILE* f, WORD* w );
 bool read_DWORD( FILE* f, DWORD* d );
 bool read_QWORD( FILE* f, QWORD* q );
 
+ENCINT get_be_ENCINT( BYTE** b );
+SRINT get_SRINT( BYTE** byte, int* bit, BYTE s, BYTE r );
+
 #include "version.h"
 
 #define AUTHOR "Pabs"
-#define AUTHOR_EMAIL "<pabs3@zip.to>"
-#define WEBSITE "http://zip.to/pabs3/"
-#define EMAIL_CHM "Please email "AUTHOR" "AUTHOR_EMAIL" about this chm.\n"
+#define AUTHOR_EMAIL "<pabs@zip.to>"
+#define WEBSITE "http://pabs.zip.to"
+#define EMAIL_CHM fprintf( stderr, "%s", "Please email "AUTHOR" "AUTHOR_EMAIL" about this chm.\n" )
 
 #if defined(__MINGW32__) || defined(_MSC_VER)
 	#define MKDIR_PERM
