@@ -475,32 +475,7 @@ void recreate_hhp( void ){
 
 /* Returns true if the argument is the name of an internal file */
 bool isinternal( char* f ){
-	return
-		!strcmp( f, "#BSSC" ) ||
-		!strcmp( f, "#GRPINF" ) ||
-		!strcmp( f, "#IDXHDR" ) ||
-		!strcmp( f, "#INFOTYPES" ) ||
-		!strcmp( f, "#ITBITS" ) ||
-		!strcmp( f, "#IVB" ) ||
-		!strcmp( f, "#KEY_DATA" ) ||
-		!strcmp( f, "#KEY_DELETED" ) ||
-		!strcmp( f, "#STRINGS" ) ||
-		!strcmp( f, "#SUBSETS" ) ||
-		!strcmp( f, "#SYSTEM" ) ||
-		!strcmp( f, "#TOCIDX" ) ||
-		!strcmp( f, "#TOPICS" ) ||
-		!strcmp( f, "#URLS" ) ||
-		!strcmp( f, "#URLSTR" ) ||
-		!strcmp( f, "#URLTBL" ) ||
-		!strcmp( f, "#WINDOWS" ) ||
-		!strcmp( f, "$FIftiMain" ) ||
-		!strcmp( f, "$HHTitleMap" ) ||
-		!strcmp( f, "$OBJINST" ) ||
-		!strcmp( f, "$TitleMap" ) ||
-		!strcmp( f, "$WWAssociativeLinks" ) ||
-		!strcmp( f, "$WWKeywordLinks" ) ||
-		/* The following may go away when "<input>-rec" in the current dir is where we recreate stuff */
-		!strcmp( f, "#recreated" ); /* Bit of a kludge, spose i should use the inode (which is not very portable) */
+	return *f == '#' || *f == '$';
 }
 
 /* Recurse through a dir, printing out the names of files found */
@@ -511,8 +486,10 @@ void print_files( char* d ){
 		struct stat st;
 		struct dirent* de;
 
-		/* On cygwin we need to enter the dir first */
+		/* On *nix we need to enter the dir first */
+#ifndef __MINGW32__
 		chdir( d );
+#endif /* __MINGW32__ */
 
 		while( (de = readdir( dir )) ){
 
@@ -566,9 +543,10 @@ void print_files( char* d ){
 			}
 		}
 
+#ifndef __MINGW32__
 		/* Back out */
 		if( !!strcmp( d, "." ) ) chdir( ".." );
-
+#endif /* __MINGW32__ */
 		closedir( dir );
 	} else
 		fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, prefix?prefix:"", d, strerror(errno) );
