@@ -24,4 +24,8 @@ void close_sitemap();
 	"</HEAD><BODY>\r\n"
 #define SITEMAP_FOOTER "</UL>\r\n</BODY></HTML>\r\n"
 
+extern FILE* topics;
+extern FILE* urltbl;
+extern FILE* urlstr;
+
 #endif /* _SITEMAP_H_ */
